@@ -28,11 +28,13 @@
     id doom2;
     id plutonia;
     id tnt;
+    id freedoom1;
+    id freedoom2;
     id freedm;
 
     id heretic;
     id hexen;
-    id strife;
+    //id strife;
 }
 
 - (void) closeConfigWindow: (id)sender;
