@@ -53,7 +53,6 @@ typedef struct
 	int demotimerdir;
 	int demobar;
 	int extautomap;
-	int extsaveg;
 	int flipcorpses;
 	int freeaim;
 	int freelook;
@@ -65,7 +64,6 @@ typedef struct
 	int overunder;
 	int pitch;
 	int playercoords;
-	int recoil;
 	int secretmessage;
 	int smoothlight;
 	int smoothmap;
@@ -73,17 +71,18 @@ typedef struct
 	int soundfix;
 	int soundfull;
 	int soundmono;
+	int statsformat;
 	int translucency;
 #ifdef CRISPY_TRUECOLOR
 	int truecolor;
 #endif
 	int uncapped;
 	int vsync;
-	int weaponsquat;
 	int widescreen;
 
 	// [crispy] in-game switches and variables
 	int screenshotmsg;
+	int snowflakes;
 	int cleanscreenshot;
 	int demowarp;
 	int fps;
@@ -95,12 +94,19 @@ typedef struct
 	boolean havee1m10;
 	boolean havemap33;
 	boolean havessg;
-	boolean pistolstart;
 	boolean singleplayer;
 	boolean stretchsky;
 
+	// [crispy] custom difficulty parameters
+	boolean autohealth;
+	boolean fast;
+	boolean keysloc;
+	boolean moreammo;
+	boolean pistolstart;
+
 	char *havenerve;
 	char *havemaster;
+	char *havesigil;
 
 	const char *sdlversion;
 	const char *platform;
@@ -222,6 +228,15 @@ enum
     NUM_WIDGETS
 };
 
+enum
+{
+    STATSFORMAT_RATIO,
+    STATSFORMAT_REMAINING,
+    STATSFORMAT_PERCENT,
+    STATSFORMAT_BOOLEAN,
+    NUM_STATSFORMATS
+};
+
 enum
 {
     RATIO_4_3,
