@@ -29,8 +29,11 @@
 #define DEH_VANILLA_NUMSTATES 966
 #define DEH_VANILLA_NUMSFX 107
 
+void DEH_Init(void); // [crispy] un-static
+
 void DEH_ParseCommandLine(void);
 int DEH_LoadFile(const char *filename);
+void DEH_AutoLoadPatches(const char *path);
 int DEH_LoadLump(int lumpnum, boolean allow_long, boolean allow_error);
 int DEH_LoadLumpByName(const char *name, boolean allow_long, boolean allow_error);
 
