@@ -65,6 +65,7 @@
 #include "a11y.h" // [crispy] A11Y
 
 #include "hu_stuff.h"
+#include "v_snow.h"
 #include "wi_stuff.h"
 #include "st_stuff.h"
 #include "am_map.h"
@@ -308,6 +309,16 @@ boolean D_Display (void)
 	inhelpscreensstate = true;
     }
 
+    // [crispy] Snow
+    if (crispy->snowflakes)
+    {
+	V_SnowDraw();
+
+	// [crispy] force redraw of status bar and border
+	viewactivestate = false;
+	inhelpscreensstate = true;
+    }
+
     // [crispy] draw neither pause pic nor menu when taking a clean screenshot
     if (crispy->cleanscreenshot)
     {
@@ -411,6 +422,7 @@ void D_BindVariables(void)
 //  M_BindIntVariable("vanilla_savegame_limit", &vanilla_savegame_limit);
 //  M_BindIntVariable("vanilla_demo_limit",     &vanilla_demo_limit);
     M_BindIntVariable("a11y_sector_lighting",   &a11y_sector_lighting);
+    M_BindIntVariable("a11y_extra_lighting",    &a11y_extra_lighting);
     M_BindIntVariable("a11y_weapon_flash",      &a11y_weapon_flash);
     M_BindIntVariable("a11y_weapon_pspr",       &a11y_weapon_pspr);
     M_BindIntVariable("a11y_palette_changes",   &a11y_palette_changes);
@@ -447,7 +459,6 @@ void D_BindVariables(void)
     M_BindIntVariable("crispy_demotimer",       &crispy->demotimer);
     M_BindIntVariable("crispy_demotimerdir",    &crispy->demotimerdir);
     M_BindIntVariable("crispy_extautomap",      &crispy->extautomap);
-    M_BindIntVariable("crispy_extsaveg",        &crispy->extsaveg);
     M_BindIntVariable("crispy_flipcorpses",     &crispy->flipcorpses);
     M_BindIntVariable("crispy_freeaim",         &crispy->freeaim);
     M_BindIntVariable("crispy_freelook",        &crispy->freelook);
@@ -459,7 +470,6 @@ void D_BindVariables(void)
     M_BindIntVariable("crispy_overunder",       &crispy->overunder);
     M_BindIntVariable("crispy_pitch",           &crispy->pitch);
     M_BindIntVariable("crispy_playercoords",    &crispy->playercoords);
-    M_BindIntVariable("crispy_recoil",          &crispy->recoil);
     M_BindIntVariable("crispy_secretmessage",   &crispy->secretmessage);
     M_BindIntVariable("crispy_smoothlight",     &crispy->smoothlight);
     M_BindIntVariable("crispy_smoothmap",       &crispy->smoothmap);
@@ -467,13 +477,13 @@ void D_BindVariables(void)
     M_BindIntVariable("crispy_soundfix",        &crispy->soundfix);
     M_BindIntVariable("crispy_soundfull",       &crispy->soundfull);
     M_BindIntVariable("crispy_soundmono",       &crispy->soundmono);
+    M_BindIntVariable("crispy_statsformat",     &crispy->statsformat);
     M_BindIntVariable("crispy_translucency",    &crispy->translucency);
 #ifdef CRISPY_TRUECOLOR
     M_BindIntVariable("crispy_truecolor",       &crispy->truecolor);
 #endif
     M_BindIntVariable("crispy_uncapped",        &crispy->uncapped);
     M_BindIntVariable("crispy_vsync",           &crispy->vsync);
-    M_BindIntVariable("crispy_weaponsquat",     &crispy->weaponsquat);
     M_BindIntVariable("crispy_widescreen",      &crispy->widescreen);
 }
 
@@ -1302,6 +1312,14 @@ static void D_Endoom(void)
     I_Endoom(endoom);
 }
 
+boolean IsFrenchIWAD(void)
+{
+    return (gamemission == doom2 && W_CheckNumForName("M_RDTHIS") < 0
+          && W_CheckNumForName("M_EPISOD") < 0 && W_CheckNumForName("M_EPI1") < 0
+          && W_CheckNumForName("M_EPI2") < 0 && W_CheckNumForName("M_EPI3") < 0
+          && W_CheckNumForName("WIOSTF") < 0 && W_CheckNumForName("WIOBJ") >= 0);
+}
+
 // Load dehacked patches needed for certain IWADs.
 static void LoadIwadDeh(void)
 {
@@ -1314,6 +1332,7 @@ static void LoadIwadDeh(void)
         DEH_LoadLumpByName("DEHACKED", false, true);
     }
 
+    else // [crispy]
     // If this is the HACX IWAD, we need to load the DEHACKED lump.
     if (gameversion == exe_hacx)
     {
@@ -1324,6 +1343,7 @@ static void LoadIwadDeh(void)
         }
     }
 
+    else // [crispy]
     // Chex Quest needs a separate Dehacked patch which must be downloaded
     // and installed next to the IWAD.
     if (gameversion == exe_chex)
@@ -1359,6 +1379,47 @@ static void LoadIwadDeh(void)
             I_Error("Failed to load chex.deh needed for emulating chex.exe.");
         }
     }
+    // [crispy] try anyway...
+    else if (W_CheckNumForName("DEHACKED") != -1)
+    {
+        DEH_LoadLumpByName("DEHACKED", true, true);
+    }
+
+    if (IsFrenchIWAD())
+    {
+        char *french_deh = NULL;
+        char *dirname;
+
+        // Look for french.deh in the same directory as the IWAD file.
+        dirname = M_DirName(iwadfile);
+        french_deh = M_StringJoin(dirname, DIR_SEPARATOR_S, "french.deh", NULL);
+        printf("French version\n");
+        free(dirname);
+
+        // If the dehacked patch isn't found, try searching the WAD
+        // search path instead.  We might find it...
+        if (!M_FileExists(french_deh))
+        {
+            free(french_deh);
+            french_deh = D_FindWADByName("french.deh");
+        }
+
+        // Still not found?
+        if (french_deh == NULL)
+        {
+            I_Error("Unable to find French Doom II dehacked file\n"
+                    "(french.deh).  The dehacked file is required in order to\n"
+                    "emulate French doom2.exe correctly.  It can be found in\n"
+                    "your nearest /idgames repository mirror at:\n\n"
+                    "   utils/exe_edit/patches/french.zip");
+        }
+
+        if (!DEH_LoadFile(french_deh))
+        {
+            I_Error("Failed to load french.deh needed for emulating French\n"
+                    "doom2.exe.");
+        }
+    }
 }
 
 static void G_CheckDemoStatusAtExit (void)
@@ -1375,7 +1436,7 @@ void D_DoomMain (void)
 {
     int p;
     char file[256];
-    char demolumpname[9];
+    char demolumpname[9] = {0};
     int numiwadlumps;
 
     // [crispy] unconditionally initialize DEH tables
@@ -1695,6 +1756,16 @@ void D_DoomMain (void)
 
     crispy->pistolstart = M_ParmExists("-pistolstart");
 
+    //!
+    // @category game
+    // @category mod
+    //
+    // Double ammo pickup rate. This option is not allowed when recording a
+    // demo, playing back a demo or when starting a network game.
+    //
+
+    crispy->moreammo = M_ParmExists("-doubleammo");
+
     //!
     // @category mod
     //
@@ -1905,7 +1976,7 @@ void D_DoomMain (void)
     W_GenerateHashTable();
 
     // [crispy] allow overriding of special-casing
-    if (!M_ParmExists("-noautoload") && gamemode != shareware)
+    if (!M_ParmExists("-nosideload") && gamemode != shareware && !demolumpname[0])
     {
 	if (gamemode == retail &&
 	    gameversion == exe_ultimate &&
