@@ -201,10 +201,6 @@ void A_FireOldBFG(mobj_t *mobj, player_t *player, pspdef_t *psp)
 
   if (!player) return; // [crispy] let pspr action pointers get called from mobj states
 
-  if (crispy->recoil && !(player->mo->flags & MF_NOCLIP))
-    P_Thrust(player, ANG180 + player->mo->angle,
-	     512*20);//recoil_values[wp_plasma][0]);
-
   player->ammo[weaponinfo[player->readyweapon].ammo]--;
 
   player->extralight = 2;
@@ -247,11 +243,17 @@ void A_FireOldBFG(mobj_t *mobj, player_t *player, pspdef_t *psp)
       th = P_SpawnMobj(mo->x, mo->y,
 		       mo->z + 62*FRACUNIT - player->psprites[ps_weapon].sy,
 		       type);
+      // [NS] Play projectile sound.
+      if (th->info->seesound)
+      {
+	S_StartSound (th, th->info->seesound);
+      }
       th->target = mo; // P_SetTarget(&th->target, mo);
       th->angle = an1;
-      th->momx = finecosine[an1>>ANGLETOFINESHIFT] * 25;
-      th->momy = finesine[an1>>ANGLETOFINESHIFT] * 25;
-      th->momz = finetangent[an2>>ANGLETOFINESHIFT] * 25;
+      // [NS] Use speed from thing info.
+      th->momx = FixedMul(th->info->speed, finecosine[an1>>ANGLETOFINESHIFT]);
+      th->momy = FixedMul(th->info->speed, finesine[an1>>ANGLETOFINESHIFT]);
+      th->momz = FixedMul(th->info->speed, finetangent[an2>>ANGLETOFINESHIFT]);
       // [crispy] suppress interpolation of player missiles for the first tic
       th->interp = -1;
       P_CheckMissileSpawn(th);
