@@ -86,7 +86,8 @@ P_GiveAmmo
 	num = clipammo[ammo]/2;
     
     if (gameskill == sk_baby
-	|| gameskill == sk_nightmare)
+	|| gameskill == sk_nightmare
+	|| critical->moreammo)
     {
 	// give double ammo in trainer mode,
 	// you'll need in nightmare
@@ -450,6 +451,7 @@ P_TouchSpecialThing
 	if (!player->cards[it_bluecard])
 	    player->message = DEH_String(GOTBLUECARD);
 	P_GiveCard (player, it_bluecard);
+	sound = sfx_keyup; // [NS] Optional key pickup sound.
 	if (!netgame)
 	    break;
 	return;
@@ -458,6 +460,7 @@ P_TouchSpecialThing
 	if (!player->cards[it_yellowcard])
 	    player->message = DEH_String(GOTYELWCARD);
 	P_GiveCard (player, it_yellowcard);
+	sound = sfx_keyup; // [NS] Optional key pickup sound.
 	if (!netgame)
 	    break;
 	return;
@@ -466,6 +469,7 @@ P_TouchSpecialThing
 	if (!player->cards[it_redcard])
 	    player->message = DEH_String(GOTREDCARD);
 	P_GiveCard (player, it_redcard);
+	sound = sfx_keyup; // [NS] Optional key pickup sound.
 	if (!netgame)
 	    break;
 	return;
@@ -474,6 +478,7 @@ P_TouchSpecialThing
 	if (!player->cards[it_blueskull])
 	    player->message = DEH_String(GOTBLUESKUL);
 	P_GiveCard (player, it_blueskull);
+	sound = sfx_keyup; // [NS] Optional key pickup sound.
 	if (!netgame)
 	    break;
 	return;
@@ -482,6 +487,7 @@ P_TouchSpecialThing
 	if (!player->cards[it_yellowskull])
 	    player->message = DEH_String(GOTYELWSKUL);
 	P_GiveCard (player, it_yellowskull);
+	sound = sfx_keyup; // [NS] Optional key pickup sound.
 	if (!netgame)
 	    break;
 	return;
@@ -490,6 +496,7 @@ P_TouchSpecialThing
 	if (!player->cards[it_redskull])
 	    player->message = DEH_String(GOTREDSKULL);
 	P_GiveCard (player, it_redskull);
+	sound = sfx_keyup; // [NS] Optional key pickup sound.
 	if (!netgame)
 	    break;
 	return;
@@ -692,6 +699,15 @@ P_TouchSpecialThing
 	sound = sfx_wpnup;	
 	break;
 		
+	// [NS] Beta pickups.
+      case SPR_BON3:
+	player->message = DEH_String(BETA_BONUS3);
+	break;
+
+      case SPR_BON4:
+	player->message = DEH_String(BETA_BONUS4);
+	break;
+
       default:
 	I_Error ("P_SpecialThing: Unknown gettable thing");
     }
@@ -701,7 +717,7 @@ P_TouchSpecialThing
     P_RemoveMobj (special);
     player->bonuscount += BONUSADD;
     if (player == &players[consoleplayer])
-	S_StartSound (NULL, sound);
+	S_StartSoundOptional (NULL, sound, sfx_itemup); // [NS] Fallback to itemup.
 }
 
 
