@@ -773,6 +773,19 @@ void S_StartSoundOnce (void *origin_p, int sfx_id)
     S_StartSound(origin_p, sfx_id);
 }
 
+// [NS] Try to play an optional sound.
+void S_StartSoundOptional(void *origin_p, int sfx_id, int old_sfx_id)
+{
+    if (I_GetSfxLumpNum(&S_sfx[sfx_id]) != -1)
+    {
+        S_StartSound(origin_p, sfx_id);
+    }
+    else if (old_sfx_id != -1) // Play a fallback?
+    {
+        S_StartSound(origin_p, old_sfx_id);
+    }
+}
+
 //
 // Stop and resume music, during game PAUSE.
 //
