@@ -451,6 +451,7 @@ cheatseq_t cheat_showfps2 = CHEAT("idrate", 0); // [crispy] PrBoom+
 cheatseq_t cheat_goobers = CHEAT("goobers", 0);
 cheatseq_t cheat_version = CHEAT("version", 0); // [crispy] Russian Doom
 cheatseq_t cheat_skill = CHEAT("skill", 0);
+cheatseq_t cheat_snow = CHEAT("letitsnow", 0);
 static char msg[ST_MSGWIDTH];
 
 // [crispy] restrict cheat usage
@@ -1161,6 +1162,11 @@ ST_Responder (event_t* ev)
 	    plyr->message = msg;
 	}
       }
+      // [crispy] snow
+      else if (cht_CheckCheatSP(&cheat_snow, ev->data2))
+      {
+    crispy->snowflakes = !crispy->snowflakes;
+      }
     }
 
 // [crispy] now follow "harmless" Crispy Doom specific cheats
