@@ -973,7 +973,7 @@ void WI_updateDeathmatchStats(void)
 	}
 	
 
-	S_StartSound(0, sfx_barexp);
+	S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	dm_state = 4;
     }
 
@@ -981,7 +981,7 @@ void WI_updateDeathmatchStats(void)
     if (dm_state == 2)
     {
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 	
 	stillticking = false;
 
@@ -1020,7 +1020,7 @@ void WI_updateDeathmatchStats(void)
 	}
 	if (!stillticking)
 	{
-	    S_StartSound(0, sfx_barexp);
+	    S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	    dm_state++;
 	}
 
@@ -1029,7 +1029,7 @@ void WI_updateDeathmatchStats(void)
     {
 	if (acceleratestage)
 	{
-	    S_StartSound(0, sfx_slop);
+	    S_StartSoundOptional(0, sfx_intdms, sfx_slop); // [NS] Optional inter sounds.
 
 	    if ( gamemode == commercial)
 		WI_initNoState();
@@ -1191,14 +1191,14 @@ void WI_updateNetgameStats(void)
 	    if (dofrags)
 		cnt_frags[i] = WI_fragSum(i);
 	}
-	S_StartSound(0, sfx_barexp);
+	S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	ng_state = 10;
     }
 
     if (ng_state == 2)
     {
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 
 	stillticking = false;
 
@@ -1217,14 +1217,14 @@ void WI_updateNetgameStats(void)
 	
 	if (!stillticking)
 	{
-	    S_StartSound(0, sfx_barexp);
+	    S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	    ng_state++;
 	}
     }
     else if (ng_state == 4)
     {
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 
 	stillticking = false;
 
@@ -1241,14 +1241,14 @@ void WI_updateNetgameStats(void)
 	}
 	if (!stillticking)
 	{
-	    S_StartSound(0, sfx_barexp);
+	    S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	    ng_state++;
 	}
     }
     else if (ng_state == 6)
     {
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 
 	stillticking = false;
 
@@ -1267,14 +1267,14 @@ void WI_updateNetgameStats(void)
 	
 	if (!stillticking)
 	{
-	    S_StartSound(0, sfx_barexp);
+	    S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	    ng_state += 1 + 2*!dofrags;
 	}
     }
     else if (ng_state == 8)
     {
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 
 	stillticking = false;
 
@@ -1293,7 +1293,7 @@ void WI_updateNetgameStats(void)
 	
 	if (!stillticking)
 	{
-	    S_StartSound(0, sfx_pldeth);
+	    S_StartSoundOptional(0, sfx_intnet, sfx_pldeth); // [NS] Optional inter sounds.
 	    ng_state++;
 	}
     }
@@ -1301,7 +1301,7 @@ void WI_updateNetgameStats(void)
     {
 	if (acceleratestage)
 	{
-	    S_StartSound(0, sfx_sgcock);
+	    S_StartSoundOptional(0, sfx_intnex, sfx_sgcock); // [NS] Optional inter sounds.
 	    if ( gamemode == commercial )
 		WI_initNoState();
 	    else
@@ -1402,7 +1402,7 @@ void WI_updateStats(void)
 	cnt_secret[0] = (plrs[me].ssecret * 100) / wbs->maxsecret;
 	cnt_time = plrs[me].stime / TICRATE;
 	cnt_par = wbs->partime / TICRATE;
-	S_StartSound(0, sfx_barexp);
+	S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	sp_state = 10;
     }
 
@@ -1411,12 +1411,12 @@ void WI_updateStats(void)
 	cnt_kills[0] += 2;
 
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 
 	if (cnt_kills[0] >= (plrs[me].skills * 100) / wbs->maxkills)
 	{
 	    cnt_kills[0] = (plrs[me].skills * 100) / wbs->maxkills;
-	    S_StartSound(0, sfx_barexp);
+	    S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	    sp_state++;
 	}
     }
@@ -1425,12 +1425,12 @@ void WI_updateStats(void)
 	cnt_items[0] += 2;
 
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 
 	if (cnt_items[0] >= (plrs[me].sitems * 100) / wbs->maxitems)
 	{
 	    cnt_items[0] = (plrs[me].sitems * 100) / wbs->maxitems;
-	    S_StartSound(0, sfx_barexp);
+	    S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	    sp_state++;
 	}
     }
@@ -1439,12 +1439,12 @@ void WI_updateStats(void)
 	cnt_secret[0] += 2;
 
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 
 	if (cnt_secret[0] >= (plrs[me].ssecret * 100) / wbs->maxsecret)
 	{
 	    cnt_secret[0] = (plrs[me].ssecret * 100) / wbs->maxsecret;
-	    S_StartSound(0, sfx_barexp);
+	    S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 	    sp_state++;
 	}
     }
@@ -1452,7 +1452,7 @@ void WI_updateStats(void)
     else if (sp_state == 8)
     {
 	if (!(bcnt&3))
-	    S_StartSound(0, sfx_pistol);
+	    S_StartSoundOptional(0, sfx_inttic, sfx_pistol); // [NS] Optional inter sounds.
 
 	cnt_time += 3;
 
@@ -1467,7 +1467,7 @@ void WI_updateStats(void)
 
 	    if (cnt_time >= plrs[me].stime / TICRATE)
 	    {
-		S_StartSound(0, sfx_barexp);
+		S_StartSoundOptional(0, sfx_inttot, sfx_barexp); // [NS] Optional inter sounds.
 		sp_state++;
 	    }
 	}
@@ -1476,7 +1476,7 @@ void WI_updateStats(void)
     {
 	if (acceleratestage)
 	{
-	    S_StartSound(0, sfx_sgcock);
+	    S_StartSoundOptional(0, sfx_intnex, sfx_sgcock); // [NS] Optional inter sounds.
 
 	    if (gamemode == commercial)
 		WI_initNoState();
