@@ -180,7 +180,8 @@ boolean P_GiveAmmo(player_t * player, ammotype_t ammo, int count)
     {
         return (false);
     }
-    if (gameskill == sk_baby || gameskill == sk_nightmare)
+    if (gameskill == sk_baby || gameskill == sk_nightmare
+                             || critical->moreammo)
     {                           // extra ammo in baby mode and nightmare mode
         count += count >> 1;
     }
@@ -1211,7 +1212,7 @@ void P_AutoUseHealth(player_t * player, int saveHealth)
             superCount = player->inventory[i].count;
         }
     }
-    if ((gameskill == sk_baby) && (normalCount * 25 >= saveHealth))
+    if ((gameskill == sk_baby || critical->autohealth) && (normalCount * 25 >= saveHealth))
     {                           // Use quartz flasks
         count = (saveHealth + 24) / 25;
         for (i = 0; i < count; i++)
@@ -1229,7 +1230,7 @@ void P_AutoUseHealth(player_t * player, int saveHealth)
             P_PlayerRemoveArtifact(player, superSlot);
         }
     }
-    else if ((gameskill == sk_baby)
+    else if ((gameskill == sk_baby || critical->autohealth)
              && (superCount * 100 + normalCount * 25 >= saveHealth))
     {                           // Use mystic urns and quartz flasks
         count = (saveHealth + 24) / 25;
@@ -1450,7 +1451,8 @@ void P_DamageMobj
             damage -= saved;
         }
         if (damage >= player->health
-            && ((gameskill == sk_baby) || deathmatch) && !player->chickenTics)
+            && ((gameskill == sk_baby) || deathmatch || critical->autohealth)
+            && !player->chickenTics)
         {                       // Try to use some inventory health
             P_AutoUseHealth(player, damage - player->health + 1);
         }
