@@ -341,6 +341,7 @@ void R_StoreWallRange(int start, int stop)
     angle_t distangle, offsetangle;
     fixed_t vtop;
     int lightnum;
+    extern boolean automapactive;
 
     // [crispy] remove MAXDRAWSEGS limit
     if (ds_p == &drawsegs[numdrawsegs])
@@ -368,6 +369,10 @@ void R_StoreWallRange(int start, int stop)
 // mark the segment as visible for auto map
     linedef->flags |= ML_MAPPED;
 
+    // [crispy] (flags & ML_MAPPED) is all we need to know for automap
+    if (automapactive && !crispy->automapoverlay)
+        return;
+
 //
 // calculate rw_distance for scale calculation
 //
