@@ -1186,7 +1186,7 @@ mobj_t *P_SpawnMobj(fixed_t x, fixed_t y, fixed_t z, mobjtype_t type)
     mobj->flags2 = info->flags2;
     mobj->damage = info->damage;
     mobj->health = info->spawnhealth;
-    if (gameskill != sk_nightmare)
+    if (gameskill != sk_nightmare && !critical->fast)
     {
         mobj->reactiontime = info->reactiontime;
     }
