@@ -472,23 +472,29 @@ void R_DrawViewBorder(void)
     }
     for (x = (viewwindowx >> crispy->hires); x < (viewwindowx + viewwidth) >> crispy->hires; x += 16)
     {
-        V_DrawPatch(x, (viewwindowy >> crispy->hires) - 4, W_CacheLumpName("bordt", PU_CACHE));
-        V_DrawPatch(x, (viewwindowy + viewheight) >> crispy->hires, W_CacheLumpName("bordb",
-                                                                 PU_CACHE));
+        V_DrawPatch(x - WIDESCREENDELTA, (viewwindowy >> crispy->hires) - 4,
+                    W_CacheLumpName("bordt", PU_CACHE));
+        V_DrawPatch(x - WIDESCREENDELTA, (viewwindowy + viewheight) >> crispy->hires,
+                    W_CacheLumpName("bordb", PU_CACHE));
     }
     for (y = (viewwindowy >> crispy->hires); y < (viewwindowy + viewheight) >> crispy->hires; y += 16)
     {
-        V_DrawPatch((viewwindowx >> crispy->hires) - 4, y, W_CacheLumpName("bordl", PU_CACHE));
-        V_DrawPatch((viewwindowx + viewwidth) >> crispy->hires, y, W_CacheLumpName("bordr",
-                                                                PU_CACHE));
+        V_DrawPatch((viewwindowx >> crispy->hires) - 4 - WIDESCREENDELTA, y,
+                     W_CacheLumpName("bordl", PU_CACHE));
+        V_DrawPatch(((viewwindowx + viewwidth) >> crispy->hires) - WIDESCREENDELTA, y,
+                      W_CacheLumpName("bordr", PU_CACHE));
     }
-    V_DrawPatch((viewwindowx >> crispy->hires) - 4, (viewwindowy >> crispy->hires) - 4, W_CacheLumpName("bordtl",
-                                                                  PU_CACHE));
-    V_DrawPatch((viewwindowx + viewwidth) >> crispy->hires, (viewwindowy >> crispy->hires) - 4,
+    V_DrawPatch((viewwindowx >> crispy->hires) - 4 - WIDESCREENDELTA,
+                (viewwindowy >> crispy->hires) - 4,
+                 W_CacheLumpName("bordtl", PU_CACHE));
+    V_DrawPatch(((viewwindowx + viewwidth) >> crispy->hires) - WIDESCREENDELTA,
+                (viewwindowy >> crispy->hires) - 4,
                 W_CacheLumpName("bordtr", PU_CACHE));
-    V_DrawPatch((viewwindowx + viewwidth) >> crispy->hires, (viewwindowy + viewheight) >> crispy->hires,
+    V_DrawPatch(((viewwindowx + viewwidth) >> crispy->hires) - WIDESCREENDELTA,
+                (viewwindowy + viewheight) >> crispy->hires,
                 W_CacheLumpName("bordbr", PU_CACHE));
-    V_DrawPatch((viewwindowx >> crispy->hires) - 4, (viewwindowy + viewheight) >> crispy->hires,
+    V_DrawPatch((viewwindowx >> crispy->hires) - 4 - WIDESCREENDELTA,
+                (viewwindowy + viewheight) >> crispy->hires,
                 W_CacheLumpName("bordbl", PU_CACHE));
 }
 
@@ -536,25 +542,31 @@ void R_DrawTopBorder(void)
             dest += (SCREENWIDTH & 63);
         }
     }
-    if (viewwindowy < 35)
+    if ((viewwindowy >> crispy->hires) < 35)
     {
         for (x = (viewwindowx >> crispy->hires); x < (viewwindowx + viewwidth) >> crispy->hires; x += 16)
         {
-            V_DrawPatch(x, (viewwindowy >> crispy->hires) - 4,
+            V_DrawPatch(x - WIDESCREENDELTA, (viewwindowy >> crispy->hires) - 4,
                         W_CacheLumpName("bordt", PU_CACHE));
         }
-        V_DrawPatch((viewwindowx >> crispy->hires) - 4, viewwindowy >> crispy->hires, W_CacheLumpName("bordl",
-                                                                  PU_CACHE));
-        V_DrawPatch((viewwindowx + viewwidth) >> crispy->hires, viewwindowy >> crispy->hires,
-                    W_CacheLumpName("bordr", PU_CACHE));
-        V_DrawPatch((viewwindowx >> crispy->hires) - 4, (viewwindowy >> crispy->hires) + 16,
+        V_DrawPatch((viewwindowx >> crispy->hires) - 4 - WIDESCREENDELTA,
+                    viewwindowy >> crispy->hires,
                     W_CacheLumpName("bordl", PU_CACHE));
-        V_DrawPatch((viewwindowx + viewwidth) >> crispy->hires, (viewwindowy >> crispy->hires) + 16,
+        V_DrawPatch(((viewwindowx + viewwidth) >> crispy->hires) - WIDESCREENDELTA,
+                    viewwindowy >> crispy->hires,
+                    W_CacheLumpName("bordr", PU_CACHE));
+        V_DrawPatch((viewwindowx >> crispy->hires) - 4 - WIDESCREENDELTA,
+                    (viewwindowy >> crispy->hires) + 16,
+                    W_CacheLumpName("bordl", PU_CACHE));
+        V_DrawPatch(((viewwindowx + viewwidth) >> crispy->hires) - WIDESCREENDELTA,
+                    (viewwindowy >> crispy->hires) + 16,
                     W_CacheLumpName("bordr", PU_CACHE));
 
-        V_DrawPatch((viewwindowx >> crispy->hires) - 4, (viewwindowy >> crispy->hires) - 4,
+        V_DrawPatch((viewwindowx >> crispy->hires) - 4 - WIDESCREENDELTA,
+                    (viewwindowy >> crispy->hires) - 4,
                     W_CacheLumpName("bordtl", PU_CACHE));
-        V_DrawPatch((viewwindowx + viewwidth) >> crispy->hires, (viewwindowy >> crispy->hires) - 4,
+        V_DrawPatch(((viewwindowx + viewwidth) >> crispy->hires) - WIDESCREENDELTA,
+                    (viewwindowy >> crispy->hires) - 4,
                     W_CacheLumpName("bordtr", PU_CACHE));
     }
 }
