@@ -25,7 +25,7 @@
 #include "SDL.h"
 #include "SDL_mixer.h"
 
-#include "i_midipipe.h"
+#include "i_winmusic.h"
 
 #include "config.h"
 #include "doomtype.h"
@@ -53,9 +53,16 @@ static boolean music_initialized = false;
 
 static boolean sdl_was_initialized = false;
 
+#if defined(_WIN32)
+static boolean win_midi_stream_opened = false;
+#endif
+
+static boolean win_midi_song_registered = false;
+
 static boolean musicpaused = false;
 static int current_music_volume;
 
+char *fluidsynth_sf_path = "";
 char *timidity_cfg_path = "";
 
 static char *temp_timidity_cfg = NULL;
@@ -92,6 +99,12 @@ static boolean WriteWrapperTimidityConfig(char *write_path)
     return true;
 }
 
+
+// putenv requires a non-const string whose lifetime is the whole program
+// so can't use a string directly, have to do this silliness
+static char sdl_mixer_disable_fluidsynth[] = "SDL_MIXER_DISABLE_FLUIDSYNTH=1";
+
+
 void I_InitTimidityConfig(void)
 {
     char *env_string;
@@ -120,7 +133,7 @@ void I_InitTimidityConfig(void)
         // timidity_cfg_path or GUS mode), then disable Fluidsynth, because
         // SDL_mixer considers Fluidsynth a higher priority than Timidity and
         // therefore can end up circumventing Timidity entirely.
-        putenv("SDL_MIXER_DISABLE_FLUIDSYNTH=1");
+        putenv(sdl_mixer_disable_fluidsynth);
     }
     else
     {
@@ -147,7 +160,11 @@ static void I_SDL_ShutdownMusic(void)
     if (music_initialized)
     {
 #if defined(_WIN32)
-        I_MidiPipe_ShutdownServer();
+        if (win_midi_stream_opened)
+        {
+            I_WIN_ShutdownMusic();
+            win_midi_stream_opened = false;
+        }
 #endif
         Mix_HaltMusic();
         music_initialized = false;
@@ -172,6 +189,8 @@ static boolean SDLIsInitialized(void)
 // Initialize music subsystem
 static boolean I_SDL_InitMusic(void)
 {
+    boolean fluidsynth_sf_is_set = false;
+
     // If SDL_mixer is not initialized, we have to initialize it
     // and have the responsibility to shut it down later on.
 
@@ -208,6 +227,26 @@ static boolean I_SDL_InitMusic(void)
 
     RemoveTimidityConfig();
 
+    // When using FluidSynth, proceed to set the soundfont path via
+    // Mix_SetSoundFonts if necessary.
+
+    if (strlen(fluidsynth_sf_path) > 0 && strlen(timidity_cfg_path) == 0)
+    {
+        if (M_FileExists(fluidsynth_sf_path))
+        {
+            fluidsynth_sf_is_set = true;
+        }
+        else
+        {
+            fprintf(stderr, "Can't find Fluidsynth soundfont.\n");
+        }
+    }
+
+    if (fluidsynth_sf_is_set)
+    {
+        Mix_SetSoundFonts(fluidsynth_sf_path);
+    }
+
     // If snd_musiccmd is set, we need to call Mix_SetMusicCMD to
     // configure an external music playback program.
 
@@ -217,11 +256,11 @@ static boolean I_SDL_InitMusic(void)
     }
 
 #if defined(_WIN32)
-    // [AM] Start up midiproc to handle playing MIDI music.
-    // Don't enable it for GUS, since it handles its own volume just fine.
-    if (snd_musicdevice != SNDDEVICE_GUS)
+    // Don't enable it for GUS or Fluidsynth, since they handle their own volume
+    // just fine.
+    if (snd_musicdevice != SNDDEVICE_GUS && !fluidsynth_sf_is_set)
     {
-        I_MidiPipe_InitServer();
+        win_midi_stream_opened = I_WIN_InitMusic();
     }
 #endif
 
@@ -247,7 +286,7 @@ static void UpdateMusicVolume(void)
     }
 
 #if defined(_WIN32)
-    I_MidiPipe_SetVolume(vol);
+    I_WIN_SetMusicVolume(vol);
 #endif
     Mix_VolumeMusic(vol);
 }
@@ -273,7 +312,7 @@ static void I_SDL_PlaySong(void *handle, boolean looping)
         return;
     }
 
-    if (handle == NULL && !midi_server_registered)
+    if (handle == NULL && !win_midi_song_registered)
     {
         return;
     }
@@ -288,9 +327,9 @@ static void I_SDL_PlaySong(void *handle, boolean looping)
     }
 
 #if defined(_WIN32)
-    if (midi_server_registered)
+    if (win_midi_song_registered)
     {
-        I_MidiPipe_PlaySong(loops);
+        I_WIN_PlaySong(looping);
     }
     else
 #endif
@@ -306,9 +345,18 @@ static void I_SDL_PauseSong(void)
         return;
     }
 
-    musicpaused = true;
+#if defined(_WIN32)
+    if (win_midi_stream_opened)
+    {
+        I_WIN_PauseSong();
+    }
+    else
+#endif
+    {
+        musicpaused = true;
 
-    UpdateMusicVolume();
+        UpdateMusicVolume();
+    }
 }
 
 static void I_SDL_ResumeSong(void)
@@ -318,9 +366,18 @@ static void I_SDL_ResumeSong(void)
         return;
     }
 
-    musicpaused = false;
+#if defined(_WIN32)
+    if (win_midi_stream_opened)
+    {
+        I_WIN_ResumeSong();
+    }
+    else
+#endif
+    {
+        musicpaused = false;
 
-    UpdateMusicVolume();
+        UpdateMusicVolume();
+    }
 }
 
 static void I_SDL_StopSong(void)
@@ -331,9 +388,9 @@ static void I_SDL_StopSong(void)
     }
 
 #if defined(_WIN32)
-    if (midi_server_registered)
+    if (win_midi_song_registered)
     {
-        I_MidiPipe_StopSong();
+        I_WIN_StopSong();
     }
     else
 #endif
@@ -352,9 +409,10 @@ static void I_SDL_UnRegisterSong(void *handle)
     }
 
 #if defined(_WIN32)
-    if (midi_server_registered)
+    if (win_midi_song_registered)
     {
-        I_MidiPipe_UnregisterSong();
+        I_WIN_UnRegisterSong();
+        win_midi_song_registered = false;
     }
     else
 #endif
@@ -367,14 +425,17 @@ static void I_SDL_UnRegisterSong(void *handle)
 }
 
 // Determine whether memory block is a .mid file 
-
-// [crispy] Reverse Choco's logic from "if (MIDI)" to "if (not MUS)"
-/*
+#if defined(_WIN32)
 static boolean IsMid(byte *mem, int len)
 {
     return len > 4 && !memcmp(mem, "MThd", 4);
 }
-*/
+#endif
+
+static boolean IsMus(byte *mem, int len)
+{
+    return len > 4 && !memcmp(mem, "MUS\x1a", 4);
+}
 
 static boolean ConvertMus(byte *musdata, int len, const char *filename)
 {
@@ -423,7 +484,7 @@ static void *I_SDL_RegisterSong(void *data, int len)
 /*
     if (IsMid(data, len) && len < MAXMIDLENGTH)
 */
-    if (len < 4 || memcmp(data, "MUS\x1a", 4)) // [crispy] MUS_HEADER_MAGIC
+    if (!IsMus(data, len)) // [crispy] MUS_HEADER_MAGIC
     {
         M_WriteFile(filename, data, len);
     }
@@ -439,15 +500,19 @@ static void *I_SDL_RegisterSong(void *data, int len)
     // we have to generate a temporary file.
 
 #if defined(_WIN32)
-    // [AM] If we do not have an external music command defined, play
-    //      music with the MIDI server.
-    if (midi_server_initialized)
+    // If we do not have an external music command defined, play
+    // music with the Windows native MIDI.
+    if (win_midi_stream_opened && (IsMus(data, len) || IsMid(data, len)))
     {
-        music = NULL;
-        if (!I_MidiPipe_RegisterSong(filename))
+        if (I_WIN_RegisterSong(filename))
         {
-            fprintf(stderr, "Error loading midi: %s\n",
-                "Could not communicate with midiproc.");
+            music = (void *) 1;
+            win_midi_song_registered = true;
+        }
+        else
+        {
+            music = NULL;
+            fprintf(stderr, "Error loading midi: Failed to register song.\n");
         }
     }
     else
