@@ -315,6 +315,24 @@ static void AdjustWindowSize(void)
 {
     if (aspect_ratio_correct || integer_scaling)
     {
+        static int old_v_w, old_v_h;
+
+        if (old_v_w > 0 && old_v_h > 0)
+        {
+          int rendered_height;
+
+          // rendered height does not necessarily match window height
+          if (window_height * old_v_w > window_width * old_v_h)
+            rendered_height = (window_width * old_v_h + old_v_w - 1) / old_v_w;
+          else
+            rendered_height = window_height;
+
+          window_width = rendered_height * SCREENWIDTH / actualheight;
+        }
+
+        old_v_w = SCREENWIDTH;
+        old_v_h = actualheight;
+#if 0
         if (window_width * actualheight <= window_height * SCREENWIDTH)
         {
             // We round up window_height if the ratio is not exact; this leaves
@@ -325,6 +343,7 @@ static void AdjustWindowSize(void)
         {
             window_width = window_height * SCREENWIDTH / actualheight;
         }
+#endif
     }
 }
 
@@ -739,15 +758,11 @@ void I_FinishUpdate (void)
             flags = SDL_GetWindowFlags(screen);
             if ((flags & SDL_WINDOW_FULLSCREEN_DESKTOP) == 0)
             {
-                int old_height;
                 SDL_GetWindowSize(screen, &window_width, &window_height);
-                old_height = window_height;
 
                 // Adjust the window by resizing again so that the window
                 // is the right aspect ratio.
                 AdjustWindowSize();
-                if (window_height < old_height)
-                    window_height = old_height;
                 SDL_SetWindowSize(screen, window_width, window_height);
             }
             CreateUpscaledTexture(false);
@@ -1523,6 +1538,18 @@ static void SetVideoMode(void)
                                 SDL_TEXTUREACCESS_STREAMING,
                                 SCREENWIDTH, SCREENHEIGHT);
 
+    // Workaround for SDL 2.0.14+ alt-tab bug (taken from Doom Retro via Prboom-plus and Woof)
+#if defined(_WIN32)
+    {
+        SDL_version ver;
+        SDL_GetVersion(&ver);
+        if (ver.major == 2 && ver.minor == 0 && (ver.patch == 14 || ver.patch == 16))
+        {
+           SDL_SetHintWithPriority(SDL_HINT_VIDEO_MINIMIZE_ON_FOCUS_LOSS, "1", SDL_HINT_OVERRIDE);
+        }
+    }
+#endif
+
     // Initially create the upscaled texture for rendering to screen
 
     CreateUpscaledTexture(true);
