@@ -451,6 +451,12 @@ static default_t	doom_defaults_list[] =
 
     CONFIG_VARIABLE_KEY(key_speed),
 
+    //!
+    // Keyboard key to fast-forward through a demo.
+    //
+
+    CONFIG_VARIABLE_KEY(key_demospeed),
+
     //!
     // If non-zero, mouse input is enabled.  If zero, mouse input is
     // disabled.
@@ -477,6 +483,13 @@ static default_t	doom_defaults_list[] =
 
     CONFIG_VARIABLE_INT(mouseb_forward),
 
+    //!
+    // Mouse button to turn on running.  When held down, the player
+    // will run while moving.
+    //
+
+    CONFIG_VARIABLE_INT(mouseb_speed),
+
     //!
     // @game hexen strife
     //
@@ -996,6 +1009,12 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_STRING(music_pack_path),
 
+    //!
+    // Full path to a soundfont file to use with FluidSynth MIDI playback.
+    //
+
+    CONFIG_VARIABLE_STRING(fluidsynth_sf_path),
+
     //!
     // Full path to a Timidity configuration file to use for MIDI
     // playback. The file will be evaluated from the directory where
@@ -1055,6 +1074,12 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_INT(a11y_sector_lighting),
 
+    //!
+    // Amount of extra light to add to the game scene.
+    //
+
+    CONFIG_VARIABLE_INT(a11y_extra_lighting),
+
     //!
     // If zero, this disables weapon flashes changing the ambient light
     // level.
@@ -2069,14 +2094,6 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_INT(crispy_extautomap),
 
-    //!
-    // @game doom
-    //
-    // Extended Savegames.
-    //
-
-    CONFIG_VARIABLE_INT(crispy_extsaveg),
-
     //!
     // @game doom
     //
@@ -2165,14 +2182,6 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_INT(crispy_playercoords),
 
-    //!
-    // @game doom
-    //
-    // Enable weapon recoil thrust.
-    //
-
-    CONFIG_VARIABLE_INT(crispy_recoil),
-
     //!
     // @game doom
     //
@@ -2229,6 +2238,14 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_INT(crispy_soundmono),
 
+    //!
+    // @game doom
+    //
+    // Level Stats Format.
+    //
+
+    CONFIG_VARIABLE_INT(crispy_statsformat),
+
     //!
     // @game doom
     //
@@ -2263,14 +2280,6 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_INT(crispy_vsync),
 
-    //!
-    // @game doom
-    //
-    // Squat down weapon on impact.
-    //
-
-    CONFIG_VARIABLE_INT(crispy_weaponsquat),
-
     //!
     // @game doom
     //
