@@ -33,6 +33,7 @@ extern int key_fire;
 extern int key_use;
 extern int key_strafe;
 extern int key_speed;
+extern int key_demospeed;  // [crispy]
 
 extern int key_jump;
 extern int key_toggleautorun;
@@ -149,6 +150,7 @@ extern int key_menu_reloadlevel; // [crispy]
 extern int mousebfire;
 extern int mousebstrafe;
 extern int mousebforward;
+extern int mousebspeed;
 
 extern int mousebjump;
 
