@@ -54,6 +54,7 @@ static int *all_mouse_buttons[] = {
     &mousebnextweapon,
     &mousebmouselook, // [crispy]
     &mousebreverse, // [crispy]
+    &mousebspeed,
     &mousebinvleft,
     &mousebinvright,
     &mousebturnleft,
@@ -113,6 +114,7 @@ static void ConfigExtraButtons(TXT_UNCAST_ARG(widget), TXT_UNCAST_ARG(unused))
     AddMouseControl(buttons_table, "Previous weapon", &mousebprevweapon);
     AddMouseControl(buttons_table, "Strafe on", &mousebstrafe);
     AddMouseControl(buttons_table, "Next weapon", &mousebnextweapon);
+    AddMouseControl(buttons_table, "Run", &mousebspeed);
     
     if (gamemission == heretic)
     {
